ResponseHeaderParserOptions class
Configuration options for the responseHeaders parser.
The responseHeaders parser sends an HTTP request and extracts a value from
the response headers (for example, pulling a cookie out of the set-cookie
header). The request portion mirrors a subset of HttpParserOptions;
headerName/cookieName control what is extracted from the response.
Constructors
-
ResponseHeaderParserOptions({String? url, HttpMethod? method, Map<
String, String> ? headers, Map<String, String> ? cookies, UserAgentDevice? userAgent, Object? payload, HttpPayload? payloadType, ProxyAPIConfig? proxyAPIConfig, String? headerName, String? cookieName}) - Creates a new ResponseHeaderParserOptions instance.
- ResponseHeaderParserOptions.fromJson(String source)
-
factory
-
ResponseHeaderParserOptions.fromMap(Map<
String, dynamic> map) -
factory
Properties
-
Optional cookie name to extract from the headerName value.
final
-
Cookies to send with the request.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerName → String?
-
The response header to extract (case-insensitive), e.g.
set-cookie.final -
headers
→ Map<
String, String> ? -
Custom HTTP request headers to send.
final
- method → HttpMethod?
-
The HTTP method to use for the request.
final
- payload → Object?
-
The payload/body to send with a POST request.
final
- payloadType → HttpPayload?
-
The format of the payload.
final
- proxyAPIConfig → ProxyAPIConfig?
-
Proxy API configuration for routing the request through a proxy.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String?
-
The target URL for the request.
final
- userAgent → UserAgentDevice?
-
The user agent device type to simulate for the request.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited